@@ -47,6 +47,7 @@ namespace encode {
 
     EncoderStatusReport::EncoderStatusReport(
         EncodeAllocator *allocator, PMOS_INTERFACE pOsInterface, bool enableMfx, bool enableRcs, bool enablecp):
+        MediaStatusReport(pOsInterface),
         m_osInterface(pOsInterface),
         m_enableMfx(enableMfx),
         m_enableRcs(enableRcs),
@@ -175,6 +176,7 @@ namespace encode {
         m_statusBufAddr[statusReportNumSkip8x8Block].offset                       = CODECHAL_OFFSETOF(EncodeStatusMfx, numSkip8x8Block);
         m_statusBufAddr[statusReportSliceReport].offset                           = CODECHAL_OFFSETOF(EncodeStatusMfx, sliceReport);
         m_statusBufAddr[statusReportLpla].offset                                  = CODECHAL_OFFSETOF(EncodeStatusMfx, lookaheadStatus);
+        m_statusBufAddr[statusReportCsEngineIdRegs].offset                        = CODECHAL_OFFSETOF(EncodeStatusMfx, csEngineIdRegs[0]);
     }
 
     MOS_STATUS EncoderStatusReport::Init(void *inputPar)
@@ -389,6 +391,12 @@ namespace encode {
         // The frame is completed, notify the observers
         if (statusReportData->codecStatus == CODECHAL_STATUS_SUCCESSFUL)
         {
+#if (_DEBUG || _RELEASE_INTERNAL)
+            if (m_enableVdboxIdReport && encodeStatusMfx)
+            {
+                ParseVdboxIdsFromBuf(encodeStatusMfx->csEngineIdRegs);
+            }
+#endif
             eStatus = NotifyObservers(encodeStatusMfx, encodeStatusRcs, statusReportData);
         }
 
@@ -411,10 +419,32 @@ namespace encode {
         return MOS_STATUS_SUCCESS;
     }
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    MOS_STATUS EncoderStatusReport::ReportUsedVdboxIds()
+    {
+        if (m_enableVdboxIdReport && m_dataStatusMfx)
+        {
+            ENCODE_CHK_NULL_RETURN(m_completedCount);
+            uint32_t completedCount = *m_completedCount;
+            for (uint32_t num = m_reportedCount; num < completedCount; num++)
+            {
+                uint32_t index = CounterToIndex(num);
+                EncodeStatusMfx* encodeStatusMfx = (EncodeStatusMfx*)(m_dataStatusMfx + index * m_statusBufSizeMfx);
+                ParseVdboxIdsFromBuf(encodeStatusMfx->csEngineIdRegs);
+            }
+            MediaStatusReport::ReportUsedVdboxIds();
+        }
+        return MOS_STATUS_SUCCESS;
+    }
+#endif
+
     MOS_STATUS EncoderStatusReport::Destroy()
     {
         ENCODE_FUNC_CALL();
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+        ReportUsedVdboxIds();
+#endif
         if (m_completedCountBuf != nullptr)
         {
             m_allocator->UnLock(m_completedCountBuf);
