@@ -356,6 +356,14 @@ namespace encode {
 
         virtual PMOS_RESOURCE GetHwCtrBuf();
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+        //!
+        //! \brief  Report Used Vdbox Ids
+        //! \return MOS_STATUS
+        //!         MOS_STATUS_SUCCESS if success, else fail reason
+        //!
+        virtual MOS_STATUS ReportUsedVdboxIds() override;
+#endif
     protected:
         //!
         //! \brief  Collect the status report information into report buffer.
